@@ -14,8 +14,8 @@
 #include <itemfetchjob.h>
 #include <itemfetchscope.h>
 
-#include <kmime/kmime_message.h>
 #include "akonadi/kmime/messageparts.h"
+#include <kmime/kmime_message.h>
 
 using namespace Akonadi;
 
@@ -28,12 +28,12 @@ void MailDirFetchAllHeaders::runTest()
 {
     timer.start();
     qDebug() << "  Listing all headers of every folder.";
-    CollectionFetchJob *clj = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive);
+    auto clj = new CollectionFetchJob(Collection::root(), CollectionFetchJob::Recursive);
     clj->fetchScope().setResource(currentInstance.identifier());
     clj->exec();
     const Collection::List list = clj->collections();
     for (const Collection &collection : list) {
-        auto *ifj = new ItemFetchJob(collection, this);
+        auto ifj = new ItemFetchJob(collection, this);
         ifj->fetchScope().fetchPayloadPart(MessagePart::Envelope);
         ifj->exec();
         QString a;
