@@ -6,14 +6,14 @@
 */
 
 #include "movetotrashcommand.h"
-#include "util_p.h"
-#include "movecommand.h"
 #include "imapsettings.h"
+#include "movecommand.h"
 #include "specialmailcollections.h"
+#include "util_p.h"
 
+#include <entitytreemodel.h>
 #include <itemfetchjob.h>
 #include <itemfetchscope.h>
-#include <entitytreemodel.h>
 using namespace Akonadi;
 MoveToTrashCommand::MoveToTrashCommand(const QAbstractItemModel *model, const Akonadi::Collection::List &folders, QObject *parent)
     : CommandBase(parent)
@@ -44,13 +44,13 @@ void MoveToTrashCommand::slotFetchDone(KJob *job)
         return;
     }
 
-    auto *fjob = static_cast<Akonadi::ItemFetchJob *>(job);
+    auto fjob = static_cast<Akonadi::ItemFetchJob *>(job);
 
     mMessages = fjob->items();
     moveMessages();
 
     if (mFolderListJobCount > 0) {
-        auto *job = new Akonadi::ItemFetchJob(mFolders[mFolderListJobCount - 1], parent());
+        auto job = new Akonadi::ItemFetchJob(mFolders[mFolderListJobCount - 1], parent());
         job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
         connect(job, &Akonadi::ItemFetchJob::result, this, &MoveToTrashCommand::slotFetchDone);
     }
@@ -59,7 +59,7 @@ void MoveToTrashCommand::slotFetchDone(KJob *job)
 void MoveToTrashCommand::execute()
 {
     if (!mFolders.isEmpty()) {
-        auto *job = new Akonadi::ItemFetchJob(mFolders[mFolderListJobCount - 1], parent());
+        auto job = new Akonadi::ItemFetchJob(mFolders[mFolderListJobCount - 1], parent());
         job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
         connect(job, &Akonadi::ItemFetchJob::result, this, &MoveToTrashCommand::slotFetchDone);
     } else if (!mMessages.isEmpty()) {
@@ -74,7 +74,7 @@ void MoveToTrashCommand::moveMessages()
 {
     const Akonadi::Collection folder = mFolders.at(mFolderListJobCount);
     if (folder.isValid()) {
-        MoveCommand *moveCommand = new MoveCommand(findTrashFolder(folder), mMessages, this);
+        auto moveCommand = new MoveCommand(findTrashFolder(folder), mMessages, this);
         connect(moveCommand, &MoveCommand::result, this, &MoveToTrashCommand::slotMoveDone);
         moveCommand->execute();
     } else {
@@ -94,19 +94,18 @@ void MoveToTrashCommand::slotMoveDone(Result result)
 
 Akonadi::Collection MoveToTrashCommand::collectionFromId(Akonadi::Collection::Id id) const
 {
-    const QModelIndex idx = Akonadi::EntityTreeModel::modelIndexForCollection(
-        mModel, Akonadi::Collection(id));
+    const QModelIndex idx = Akonadi::EntityTreeModel::modelIndexForCollection(mModel, Akonadi::Collection(id));
     return idx.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 }
 
 Akonadi::Collection MoveToTrashCommand::trashCollectionFromResource(const Akonadi::Collection &col)
 {
-    //NOTE(Andras): from kmail/kmkernel.cpp
+    // NOTE(Andras): from kmail/kmkernel.cpp
     Akonadi::Collection trashCol;
     if (col.isValid()) {
         if (col.resource().contains(IMAP_RESOURCE_IDENTIFIER)) {
-            //TODO: we really need some standard interface to query for special collections,
-            //instead of relying on a resource's settings interface
+            // TODO: we really need some standard interface to query for special collections,
+            // instead of relying on a resource's settings interface
             OrgKdeAkonadiImapSettingsInterface *iface = Util::createImapSettingsInterface(col.resource());
             if (iface->isValid()) {
                 trashCol = Akonadi::Collection(iface->trashCollection());
